[Numpy-svn] r4639 - in branches/distutils_scons_command: . numpy/distutils

numpy-svn at scipy.org numpy-svn at scipy.org
Sat Dec 22 04:29:16 EST 2007


Author: cdavid
Date: 2007-12-22 03:29:10 -0600 (Sat, 22 Dec 2007)
New Revision: 4639

Modified:
   branches/distutils_scons_command/
   branches/distutils_scons_command/numpy/distutils/misc_util.py
Log:
Merged revisions 4611-4638 via svnmerge from 
http://svn.scipy.org/svn/numpy/branches/cleanconfig_rtm

................
  r4612 | cdavid | 2007-12-18 17:58:13 +0900 (Tue, 18 Dec 2007) | 3 lines
  
  Initialized merge tracking via "svnmerge" with revisions "1-4611" from 
  http://svn.scipy.org/svn/numpy/trunk
................
  r4613 | cdavid | 2007-12-18 18:26:38 +0900 (Tue, 18 Dec 2007) | 1 line
  
  Clean ndarrayobject.h headers: do not use SIZEOF_*, but NPY_SIZEOF...
................
  r4614 | cdavid | 2007-12-18 18:33:11 +0900 (Tue, 18 Dec 2007) | 1 line
  
  Refactor the NPY_ALLOW_THREAD logic outside config.h generation, and put it inside numpy headers
................
  r4615 | cdavid | 2007-12-18 18:46:34 +0900 (Tue, 18 Dec 2007) | 1 line
  
  separate config.h (private header) and numpyconfig.h (public header)
................
  r4616 | cdavid | 2007-12-18 18:57:21 +0900 (Tue, 18 Dec 2007) | 2 lines
  
  Add CHAR_BITS as a public symbol in numpyconfig header
................
  r4617 | cdavid | 2007-12-18 19:05:38 +0900 (Tue, 18 Dec 2007) | 1 line
  
  Fix escaping problem when generating numpyconfig.h on win32
................
  r4628 | cdavid | 2007-12-22 12:20:08 +0900 (Sat, 22 Dec 2007) | 1 line
  
  Add code to test for a declaration in header
................
  r4629 | cdavid | 2007-12-22 14:52:38 +0900 (Sat, 22 Dec 2007) | 1 line
  
  Add a check_decl function to check for declaration
................
  r4630 | cdavid | 2007-12-22 15:28:11 +0900 (Sat, 22 Dec 2007) | 1 line
  
  Remove distutils test for C declaration from numpy.core, since it is put in distutils now
................
  r4631 | cdavid | 2007-12-22 15:58:15 +0900 (Sat, 22 Dec 2007) | 18 lines
  
  Merged revisions 4612-4630 via svnmerge from 
  http://svn.scipy.org/svn/numpy/trunk
  
  ........
    r4620 | cdavid | 2007-12-18 19:41:22 +0900 (Tue, 18 Dec 2007) | 3 lines
    
    Initialized merge tracking via "svnmerge" with revisions "1-4619" from 
    http://svn.scipy.org/svn/numpy/branches/distutils_scons_command
  ........
    r4624 | rc | 2007-12-20 19:30:45 +0900 (Thu, 20 Dec 2007) | 2 lines
    
    fixed setmember1d for string arrays
  ........
    r4626 | stefan | 2007-12-21 18:00:24 +0900 (Fri, 21 Dec 2007) | 2 lines
    
    Add test for setdiff1d on character arrays.
  ........
................
  r4638 | cdavid | 2007-12-22 18:21:25 +0900 (Sat, 22 Dec 2007) | 1 line
  
  Get MATHLIB from numpyconfig.h, not from config.h anymore
................



Property changes on: branches/distutils_scons_command
___________________________________________________________________
Name: svnmerge-integrated
   - /branches/cleanconfig_rtm:1-4610 /branches/distutils-revamp:1-2752 /branches/distutils_scons_command:1-4619 /branches/multicore:1-3687 /branches/numpy.scons:1-4484 /trunk:1-2871
   + /branches/cleanconfig_rtm:1-4638 /branches/distutils-revamp:1-2752 /branches/distutils_scons_command:1-4619 /branches/multicore:1-3687 /branches/numpy.scons:1-4484 /trunk:1-2871

Modified: branches/distutils_scons_command/numpy/distutils/misc_util.py
===================================================================
--- branches/distutils_scons_command/numpy/distutils/misc_util.py	2007-12-22 09:21:25 UTC (rev 4638)
+++ branches/distutils_scons_command/numpy/distutils/misc_util.py	2007-12-22 09:29:10 UTC (rev 4639)
@@ -112,11 +112,11 @@
     return minrelpath(joined)
 
 def get_mathlibs(path=None):
     """Return the MATHLIB line from config.h
     """
     if path is None:
         path = os.path.join(get_numpy_include_dirs()[0], 'numpy')
-    config_file = os.path.join(path,'config.h')
+    config_file = os.path.join(path,'numpyconfig.h')
     fid = open(config_file)
     mathlibs = []
     s = '#define MATHLIB'
@@ -112,11 +112,11 @@
 
 def get_mathlibs(path=None):
-    """Return the MATHLIB line from config.h
+    """Return the MATHLIB line from numpyconfig.h
     """
     if path is None:




More information about the Numpy-svn mailing list